@@ -182,7 +182,10 @@ class Executor:
 
             if terminate:
                 logger.debug(f'terminating process')
-                process.terminate()
+                try:
+                    process.terminate()
+                except Exception as e:
+                    logger.exception(e)
             process.join(timeout=2)
             if not process.is_alive():
                 process.close()
